@@ -48,7 +48,7 @@ public class Version {
         "linux-gnu";
 
     private static final String distro_package_version =
-        "Arch Linux ARM build 7.u231_2.6.19-1-aarch64";
+        "Arch Linux ARM build 7.u231_2.6.19-1.1-aarch64";
 
     private static final String jdk_revid =
         "";
